@@ -1,12 +1,14 @@
 import os
 from typing import Optional, Union
 from deta import Deta, _Base
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, ModelMetaclass, Field
+from pydantic.main import ModelMetaclass
 from datetime import datetime
 
 
-class DetaModelMetaclass(type):
-    def __new__(cls, clsname, bases, attrs, db_name: Optional[str] = None):
+class DetaModelMetaclass(ModelMetaclass):
+    def __new__(cls, clsname, bases, attrs, **kwargs):
+        db_name = kwargs.pop('db_name', None)
         attrs['__base_name__'] = attrs.get('__base_name__', db_name)
         return super(DetaModelMetaclass, cls).__new__(cls, clsname, bases, attrs)
 
